Index: /CKEditor/branches/versions/3.3.x/_source/plugins/maximize/plugin.js
===================================================================
--- /CKEditor/branches/versions/3.3.x/_source/plugins/maximize/plugin.js	(revision 5511)
+++ /CKEditor/branches/versions/3.3.x/_source/plugins/maximize/plugin.js	(revision 5512)
@@ -81,9 +81,18 @@
 	function refreshCursor( editor )
 	{
-		// Refresh 'contentEditable' otherwise
-		// DOM lifting breaks design mode. (#5560) 
-		var body = editor.document.getBody();
-		body.setAttribute( 'contentEditable', false );
-		body.setAttribute( 'contentEditable', true );
+		// Refresh all editor instances on the page (#5724). 
+		var all = CKEDITOR.instances;
+		for ( var i in all )
+		{
+			var one = all[ i ];
+			if ( one.mode == 'wysiwyg' )
+			{
+				var body = one.document.getBody();
+				// Refresh 'contentEditable' otherwise
+				// DOM lifting breaks design mode. (#5560)
+				body.setAttribute( 'contentEditable', false );
+				body.setAttribute( 'contentEditable', true );
+			}
+		}
 
 		if ( editor.focusManager.hasFocus )
